package com.vendor.burn.model.cmdline.adapter;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.log.Log;
import com.vendor.burn.model.FlashType;
import com.vendor.burn.model.TransferWay;
import com.vendor.burn.model.cmdline.EBurnBoot;
import com.vendor.burn.model.cmdline.adapter.CommonAdapter;
import com.vendor.burn.model.config.BurnConfig;
import com.vendor.burn.model.devices.unknown.UnknownDevice;
import com.vendor.burn.views.FastbootView;
import java.io.File;
import java.util.List;
import org.eclipse.osgi.util.NLS;

public class BootBurn extends CommonAdapter {
  private UnknownDevice device;
  
  private String chipName;
  
  private TransferWay mode;
  
  private String port;
  
  private FlashType flashType;
  
  private File bootFile;
  
  private File programmer;
  
  private List<String> serialPorts;
  
  public boolean parseAllParameter(String[] args, int paramSize, boolean isCheck) {
    if (!parseChipName(args, paramSize, EBurnBoot.chipName.ordinal())) {
      printBurnBootEg();
      return false;
    } 
    if (!parseMode(args, paramSize, EBurnBoot.mode.ordinal())) {
      printBurnBootEg();
      return false;
    } 
    TransferWay transferWayStr = getMode();
    if (transferWayStr != null)
      BurnConfig.setTransferway(transferWayStr); 
    int flashNumber = EBurnBoot.flash.ordinal();
    int bootFileNumber = EBurnBoot.boot.ordinal();
    int programmerFileNumber = EBurnBoot.programmer.ordinal();
    if (this.mode != TransferWay.USBBootrom) {
      if (!parsePort(args, paramSize, EBurnBoot.port.ordinal())) {
        printBurnBoot();
        return false;
      } 
    } else {
      flashNumber--;
      bootFileNumber--;
      programmerFileNumber--;
    } 
    if (!parseFlash(args, paramSize, flashNumber)) {
      printBurnBootEg();
      return false;
    } 
    if (!isCheck)
      return true; 
    String bootFilePath = parseFile(args, paramSize, EBurnBoot.boot.name(), bootFileNumber);
    if (bootFilePath == null) {
      printBurnBootEg();
      return false;
    } 
    setBootFile(new File(bootFilePath));
    if (paramSize < programmerFileNumber)
      return true; 
    String programmerFilePath = parseFile(args, paramSize, EBurnBoot.programmer.name(), programmerFileNumber);
    if (programmerFilePath != null)
      setProgrammer(new File(programmerFilePath)); 
    return true;
  }
  
  public boolean parseChipName(String[] args, int paramSize, int chipNameNumber) {
    if (args == null) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.chipName.name()));
      return false;
    } 
    if (paramSize >= chipNameNumber) {
      String chipName = args[chipNameNumber];
      boolean result = (chipName == null || chipName.isEmpty());
      if (result) {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_IsNull, EBurnBoot.chipName.name()));
        return false;
      } 
      String upperCaseChipName = convertChipName(chipName);
      UnknownDevice device = new UnknownDevice(upperCaseChipName);
      if (!device.isValid()) {
        Log.errorln(Messages.FastbootView_Unsupported_Device);
        return false;
      } 
      FastbootView.setCurrentChipNameType(device.getChipNameType());
      setChipName(upperCaseChipName);
      setDevice(device);
      return true;
    } 
    Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.chipName.name()));
    return false;
  }
  
  public boolean parseMode(String[] args, int paramSize, int modeNumber) {
    if (args == null) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.mode.name()));
      printModeOptions();
      return false;
    } 
    if (paramSize >= modeNumber) {
      String modeStr = args[modeNumber];
      if (modeStr == null || modeStr.isEmpty()) {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_IsNull, EBurnBoot.mode.name()));
        printModeOptions();
        return false;
      } 
      if (modeStr.equalsIgnoreCase(EMode.serial.name())) {
        setMode(TransferWay.Serial);
      } else if (modeStr.equalsIgnoreCase(EMode.jtag.name())) {
        setMode(TransferWay.JTAG);
      } else if (modeStr.equalsIgnoreCase(EMode.jtagandserial.name())) {
        setMode(TransferWay.JTAGAndSerial);
      } else if (modeStr.equalsIgnoreCase(EMode.usb.name())) {
        setMode(TransferWay.USBBootrom);
      } else {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_Invalid, EBurnBoot.mode.name()));
        printModeOptions();
        return false;
      } 
      return true;
    } 
    Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.mode.name()));
    printModeOptions();
    return false;
  }
  
  public boolean parsePort(String[] args, int paramSize, int portNumber) {
    if (args == null) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.port.name()));
      return false;
    } 
    if (paramSize >= portNumber) {
      String portStr = args[portNumber];
      if (portStr == null || portStr.isEmpty()) {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_IsNull, EBurnBoot.mode.name()));
        return false;
      } 
      setPort(portStr);
      return true;
    } 
    Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.port.name()));
    return false;
  }
  
  public boolean parseFlash(String[] args, int paramSize, int flashNumber) {
    if (args == null) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.flash.name()));
      printFlashOptions();
      return false;
    } 
    if (paramSize >= flashNumber) {
      String flashStr = args[flashNumber];
      if (flashStr == null || flashStr.isEmpty()) {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_IsNull, EBurnBoot.flash.name()));
        printFlashOptions();
        return false;
      } 
      if (flashStr.equalsIgnoreCase(EFlashType.nand.name())) {
        setFlashType(FlashType.nand);
      } else if (flashStr.equalsIgnoreCase(EFlashType.spi.name())) {
        setFlashType(FlashType.spi);
      } else if (flashStr.equalsIgnoreCase(EFlashType.emmc.name())) {
        setFlashType(FlashType.emmc);
      } else if (flashStr.equalsIgnoreCase(EFlashType.ddr.name())) {
        setFlashType(FlashType.ddr);
      } else {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_Invalid, EBurnBoot.flash.name()));
        printFlashOptions();
        return false;
      } 
      return true;
    } 
    Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.flash.name()));
    printFlashOptions();
    return false;
  }
  
  private void printModeOptions() {
    Log.println("mode:");
    EMode[] eModes = EMode.values();
    for (EMode eMode : eModes)
      Log.println(eMode.name()); 
  }
  
  private void printPortOption() {
    Log.println("Input Port:");
    if (this.serialPorts != null && this.serialPorts.size() > 0)
      for (String serialPort : this.serialPorts)
        Log.println(serialPort);  
  }
  
  private void printFlashOptions() {
    Log.println("Flash:");
    EFlashType[] eFlashTypes = EFlashType.values();
    for (EFlashType eFlashType : eFlashTypes)
      Log.println(eFlashType.name()); 
  }
  
  private void printBootOption() {
    Log.println("Input Boot file:");
  }
  
  private void printProgrammerOption() {
    Log.println("Input Programmer file:(Options)");
  }
  
  public static void printBurnBootEg() {
    Log.println("burntoolcli.jar --burnboot  <chipName>   <mode>  <port>  <flash>       <boot>                 [programmer]         ");
    Log.println("burntoolcli.jar --burnboot  chipName  serial   COM0     emmc    image/fastboot.bin   image/advca_programmer.sig ");
  }
  
  public void printBurnBoot() {
    printBurnBootEg();
    printModeOptions();
    printPortOption();
    printFlashOptions();
    printBootOption();
    printProgrammerOption();
  }
  
  public UnknownDevice getDevice() {
    return this.device;
  }
  
  public void setDevice(UnknownDevice device) {
    this.device = device;
  }
  
  public String getChipName() {
    return this.chipName;
  }
  
  public void setChipName(String chipName) {
    this.chipName = chipName;
  }
  
  public TransferWay getMode() {
    return this.mode;
  }
  
  public void setMode(TransferWay mode) {
    this.mode = mode;
  }
  
  public String getPort() {
    return this.port;
  }
  
  public void setPort(String port) {
    this.port = port;
  }
  
  public FlashType getFlashType() {
    return this.flashType;
  }
  
  public void setFlashType(FlashType flashType) {
    this.flashType = flashType;
  }
  
  public File getBootFile() {
    return this.bootFile;
  }
  
  public void setBootFile(File bootFile) {
    this.bootFile = bootFile;
  }
  
  public File getProgrammer() {
    return this.programmer;
  }
  
  public void setProgrammer(File programmer) {
    this.programmer = programmer;
  }
  
  public List<String> getSerialPorts() {
    return this.serialPorts;
  }
  
  public void setSerialPorts(List<String> serialPorts) {
    this.serialPorts = serialPorts;
  }
}
